@@ -147,8 +147,6 @@ ATTR_extraresc,
 ATTR_schedversion,
 ATTR_acctkeepdays,
 ATTR_lockfile,
-ATTR_LockfileUpdateTime,
-ATTR_LockfileCheckTime,
 ATTR_credentiallifetime,
 ATTR_jobmustreport,
 ATTR_checkpoint_dir,
@@ -157,5 +155,9 @@ ATTR_jobsuffixalias,
 ATTR_mailsubjectfmt,
 ATTR_mailbodyfmt,
 ATTR_npdefault,
+ATTR_clonebatchsize,
+ATTR_clonebatchdelay,
 ATTR_jobstarttimeout,
 ATTR_jobforcecanceltime,
+ATTR_maxarraysize,
+ATTR_maxslotlimit,
