@@ -137,10 +137,6 @@ static const char *pbs_destn_file = PBS_DEFAULT_FILE;
 
 char *pbs_server = NULL;
 
-void empty_alarm_handler(int signo)
-  {
-  }
-
 
 /**
  * Attempts to get a list of server names.  Trys first
@@ -420,11 +416,11 @@ static int PBSD_authenticate(
                   strerror(errno));
           }
 
-        /* cannot locate iff in default location - search PATH */
+        /* cannot locate iff in default location or  PATH */
 
         iffpath[0] = '\0';
 
-        return(-1);
+        return(PBSE_IFF_NOT_FOUND);
         }
       }
     }    /* END if (iffpath[0] == '\0') */
@@ -562,6 +558,7 @@ int pbs_original_connect(
   struct hostent *hp;
   int out;
   int i;
+  int auth;
 
   struct passwd *pw;
   int use_unixsock = 0;
@@ -811,20 +808,32 @@ int pbs_original_connect(
 
     /* Have pbs_iff authenticate connection */
 
-    if ((ENABLE_TRUSTED_AUTH == FALSE) && (PBSD_authenticate(connection[out].ch_socket) != 0))
+    if ((ENABLE_TRUSTED_AUTH == FALSE) && ((auth = PBSD_authenticate(connection[out].ch_socket)) != 0))
       {
       close(connection[out].ch_socket);
 
       connection[out].ch_inuse = 0;
 
-      pbs_errno = PBSE_PERM;
-
-      if (getenv("PBSDEBUG"))
+      if (auth == PBSE_IFF_NOT_FOUND)
         {
-        fprintf(stderr, "ERROR:  cannot authenticate connection to server \"%s\", errno=%d (%s)\n",
-                server,
-                errno,
-                strerror(errno));
+        pbs_errno = PBSE_IFF_NOT_FOUND;
+        
+        if (getenv("PBSDEBUG"))
+          {
+          fprintf(stderr, "ERROR:  cannot find pbs_iif executable\n");
+          }
+        }
+      else
+        {
+        pbs_errno = PBSE_PERM;
+
+        if (getenv("PBSDEBUG"))
+          {
+          fprintf(stderr, "ERROR:  cannot authenticate connection to server \"%s\", errno=%d (%s)\n",
+                  server,
+                  errno,
+                  strerror(errno));
+          }
         }
 
       return(-1);
@@ -881,22 +890,20 @@ int pbs_disconnect(
 
     /* set alarm to break out of potentially infinite read */
 
-    /* act.sa_handler = SIG_IGN; */
-    act.sa_handler = empty_alarm_handler;  /* need SOME handler or blocking read never gets interrupted */
-
+    act.sa_handler = SIG_IGN;
     sigemptyset(&act.sa_mask);
     act.sa_flags = 0;
     sigaction(SIGALRM, &act, &oldact);
 
     atime = alarm(pbs_tcp_timeout);
 
+    /* NOTE:  alarm will break out of blocking read even with sigaction ignored */
+
     while (1)
       {
       /* wait for server to close connection */
 
-      /* NOTE:  if read of 'sock' is blocking, request below may hang forever 
-       * hence the signal handler empty_alarm_handler above 
-       */
+      /* NOTE:  if read of 'sock' is blocking, request below may hang forever */
 
       if (read(sock, &x, sizeof(x)) < 1)
         break;
@@ -948,8 +955,6 @@ int pbs_connect(char *server_name_ptr)    /* I (optional) */
   if (server_name_ptr && server_name_ptr[0])
     {
     strncpy(server_name_list, server_name_ptr, sizeof(server_name_list) - 1);
-    strcat(server_name_list, ",");
-    strncat(server_name_list, pbs_get_server_list(), sizeof(server_name_list) -1 - strlen(server_name_ptr) - 1);
 
     if (getenv("PBSDEBUG"))
       {
