@@ -199,6 +199,8 @@ extern int h_errno;
 int RPPTimeOut = DEFAULT_RPP_TIMEOUT;
 int RPPRetry   = DEFAULT_RPP_RETRY;
 
+char *server_alias = NULL;
+
 /* external prototypes */
 
 void rpp_shutdown_on_exit(int, void *);
@@ -2709,6 +2711,43 @@ int rpp_open(
 
   rpp_alist(hp, sp);
 
+  if(server_alias)
+    {
+    hp = gethostbyname(server_alias);
+
+    if(hp)
+      {
+      if(sp->addr_array == NULL)
+        {
+        sp->addr_array = (struct in_addr *)calloc(1, sizeof(struct in_addr));
+        if(sp->addr_array)
+          {
+          memcpy(&sp->addr_array[0], hp->h_addr_list[0], hp->h_length);
+          }
+        }
+      else
+        {
+        struct in_addr *tmp_array;
+        int j;
+
+        for(i = 0; &sp->addr_array[i] != NULL; i++);
+          
+        tmp_array = ( struct in_addr *)calloc(i, sizeof(struct in_addr));
+
+        if(tmp_array)
+          {
+          for(j = 0; j < i; j++)
+            {
+            memcpy(&tmp_array[j], &sp->addr_array[j], hp->h_length);
+            }
+          memcpy(&tmp_array[i], hp->h_addr_list[0], hp->h_length);
+          }
+        }
+      }
+    }
+
+  
+
   sp->stream_id = stream; /* use my streamid for HELLO1 */
   sp->state = RPP_OPEN_WAIT;
   sp->open_key = open_key++;
