@@ -104,7 +104,7 @@
 #include <st_client.h>
 #endif    /* IBM SP2 */
 
-static char ident[] = "@(#) $RCSfile$ $Revision: 2367 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 3230 $";
 
 /* Global Variables */
 
@@ -114,7 +114,7 @@ extern tlist_head svr_alljobs;
 extern int  termin_child;
 extern char *path_home;
 
-extern void    state_to_server A_((int, int));
+extern void    state_to_server(int, int);
 
 /* Private variables */
 static int     job_key;
