@@ -89,7 +89,6 @@
  *
  *   job_clone    clones a job (for use with job_arrays)
  *   job_clone_wt work task for cloning a job
- *   job_unlink_file() unlinks a given file using job credentials
  *
  * Include private function:
  *   job_init_wattr() initialize job working attribute array to "unspecified"
@@ -148,7 +147,7 @@ void job_purge(job *);
 extern void mom_checkpoint_delete_files(job *pjob);
 
 #if IBM_SP2==2  /* IBM SP PSSP 3.1 */
-void unload_sp_switch A_((job *pjob));
+void unload_sp_switch(job *pjob);
 #endif   /* IBM SP */
 
 #ifdef PENABLE_LINUX26_CPUSETS
@@ -156,7 +155,7 @@ extern int use_cpusets(job *);
 #endif /* PENABLE_LINUX26_CPUSETS */
 /* Local Private Functions */
 
-static void job_init_wattr A_((job *));
+static void job_init_wattr(job *);
 
 /* Global Data items */
 
@@ -172,9 +171,8 @@ extern int   LOGLEVEL;
 extern tlist_head svr_newjobs;
 extern tlist_head svr_alljobs;
 
-
-void nodes_free A_((job *));
-int TTmpDirName A_((job *, char *));
+void nodes_free(job *);
+int TTmpDirName(job *, char *);
 
 
 void tasks_free(
@@ -247,7 +245,7 @@ int remtree(
   char  namebuf[MAXPATHLEN], *filnam;
   int  i;
   int  rtnv = 0;
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   struct stat64 sb;
 #else
@@ -255,7 +253,7 @@ int remtree(
   struct stat sb;
 #endif
 
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
 
   if (lstat64(dirname, &sb) == -1)
 #else
@@ -295,7 +293,7 @@ int remtree(
 
       strcpy(filnam, pdir->d_name);
 
-#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64) && defined(LARGEFILE_WORKS)
       if (lstat64(namebuf, &sb) == -1)
 #else
       if (lstat(namebuf, &sb) == -1)
@@ -486,7 +484,6 @@ job_alloc(void)
   pj->ji_globid = NULL;
   pj->ji_stdout = 0;
   pj->ji_stderr = 0;
-  pj->ji_qs.ji_un.ji_momt.ji_exitstat = 0;
 
   pj->ji_momhandle = -1;  /* mark mom connection invalid */
 
@@ -551,40 +548,6 @@ void job_free(
   return;
   }  /* END job_free() */
 
-/*
- * job_unlink_file - unlink file, but drop root credentials before
- * doing this to avoid removing objects that aren't belong to the user.
- */
-int job_unlink_file(
-  job *pjob,		/* I */
-  const char *name)	/* I */
-  {
-  int saved_errno = 0, result = 0;
-  uid_t uid = geteuid();
-  gid_t gid = getegid();
-
-  if (uid != 0)
-    return unlink(name);
-
-  if ((setegid(pjob->ji_qs.ji_un.ji_momt.ji_exgid) == -1))
-    return -1;
-  if ((seteuid(pjob->ji_qs.ji_un.ji_momt.ji_exuid) == -1))
-    {
-    saved_errno = errno;
-    setegid(gid);
-    errno = saved_errno;
-    return -1;
-    }
-  result = unlink(name);
-  saved_errno = errno;
-
-  seteuid(uid);
-  setegid(gid);
-
-  errno = saved_errno;
-  return result;
-  }  /* END job_unlink_file() */
-
 
 /*
  * job_init_wattr - initialize job working attribute array
@@ -628,52 +591,8 @@ void job_purge(
   char          namebuf[MAXPATHLEN + 1];
   extern char  *msg_err_purgejob;
   int           rc;
-  int           pid;
 
-  extern void MOMCheckRestart A_((void));
-
-  pid = fork();
-  if(pid < 0)
-    {
-    sprintf(log_buffer, "fork() failed in job_purge: %d", errno);
-    log_record(
-      PBSEVENT_DEBUG,
-      PBS_EVENTCLASS_JOB,
-      pjob->ji_qs.ji_jobid,
-      log_buffer);
-
-    return;
-    }
-
-  if(pid != 0)
-    {
-    /* we are the parent.*/
-    delete_link(&pjob->ji_jobque);
-
-    delete_link(&pjob->ji_alljobs);
-
-    if (LOGLEVEL >= 6)
-      {
-      sprintf(log_buffer,"removing job");
-
-      log_record(
-        PBSEVENT_DEBUG,
-        PBS_EVENTCLASS_JOB,
-        pjob->ji_qs.ji_jobid,
-        log_buffer);
-      }
-    job_free(pjob);
-
-    /* if no jobs are left, check if MOM should be restarted */
-
-    if (((job *)GET_NEXT(svr_alljobs)) == NULL)
-      MOMCheckRestart();
-
-    return;
-    }
-
-
-  /* This is the child */
+  extern void MOMCheckRestart(void);
 
   if (pjob->ji_flags & MOM_HAS_TMPDIR)
     {
@@ -693,7 +612,7 @@ void job_purge(
         {
         /* FAILURE */
 
-        _exit(1);
+        return;
         }
 
       rc = remtree(namebuf);
@@ -743,6 +662,21 @@ void job_purge(
     pjob->ji_flags &= ~MOM_HAS_NODEFILE;
     }
 
+  delete_link(&pjob->ji_jobque);
+
+  delete_link(&pjob->ji_alljobs);
+
+  if (LOGLEVEL >= 6)
+    {
+    sprintf(log_buffer,"removing job");
+
+    log_record(
+      PBSEVENT_DEBUG,
+      PBS_EVENTCLASS_JOB,
+      pjob->ji_qs.ji_jobid,
+      log_buffer);
+    }
+
   strcpy(namebuf,path_jobs); /* delete script file */
 
   strcat(namebuf,pjob->ji_qs.ji_fileprefix);
@@ -801,8 +735,14 @@ void job_purge(
       log_buffer);
     }
 
-  /* use _exit so we do not run any of the at_exit or on_exit routines */
-  _exit(0);
+  job_free(pjob);
+
+  /* if no jobs are left, check if MOM should be restarted */
+
+  if (((job *)GET_NEXT(svr_alljobs)) == NULL)
+    MOMCheckRestart();
+
+  return;
   }  /* END job_purge() */
 
 
