@@ -173,8 +173,8 @@ static int            max_proc = 0;
 /*
 ** external functions and data
 */
-extern struct	config		*search A_((struct config *,char *));
-extern struct	rm_attribute	*momgetattr A_((char *));
+extern struct	config		*search(struct config *,char *);
+extern struct	rm_attribute	*momgetattr(char *);
 extern int                      rm_errno;
 extern double	cputfactor;
 extern double	wallfactor;
@@ -187,14 +187,14 @@ extern int      ignmem;
 /*
 ** local functions and data
 */
-static char *resi     A_((struct rm_attribute *));
-static char *totmem   A_((struct rm_attribute *));
-static char *availmem A_((struct rm_attribute *));
-static char *physmem  A_((struct rm_attribute *));
-static char *ncpus    A_((struct rm_attribute *));
-static char *walltime A_((struct rm_attribute *));
-static char *quota    A_((struct rm_attribute *));
-static char *netload  A_((struct rm_attribute *));
+static char *resi     (struct rm_attribute *);
+static char *totmem   (struct rm_attribute *);
+static char *availmem (struct rm_attribute *);
+static char *physmem  (struct rm_attribute *);
+static char *ncpus    (struct rm_attribute *);
+static char *walltime (struct rm_attribute *);
+static char *quota    (struct rm_attribute *);
+static char *netload  (struct rm_attribute *);
 
 #ifndef mbool_t
 #define mbool_t char
@@ -202,8 +202,8 @@ static char *netload  A_((struct rm_attribute *));
 
 mbool_t ProcIsChild(char *,char *,char *);
 
-extern char *loadave A_((struct rm_attribute *));
-extern char *nullproc A_((struct rm_attribute *));
+extern char *loadave(struct rm_attribute *);
+extern char *nullproc(struct rm_attribute *);
 
 time_t wait_time = 10;
 
@@ -517,7 +517,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-        /*mm.mem_total *= 1024;*/ /* the unit is kB */
+        mm.mem_total *= 1024; /* the unit is kB */
         }
       else if (!strncmp(str, "MemFree:", sizeof(str)))
         {
@@ -527,7 +527,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-        /* mm.mem_free *= 1024;*/
+        mm.mem_free *= 1024;
         }
       else if (!strncmp(str, "Buffers:", sizeof(str)))
         {
@@ -537,7 +537,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-         mm.mem_free += bfsz/* * 1024*/;
+        mm.mem_free += bfsz * 1024;
         }
       else if (!strncmp(str, "Cached:", sizeof(str)))
         {
@@ -547,7 +547,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-        mm.mem_free += casz/* * 1024*/;
+        mm.mem_free += casz * 1024;
         }
       else if (!strncmp(str, "SwapTotal:", sizeof(str)))
         {
@@ -557,7 +557,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-        /* mm.swap_total *= 1024; */
+        mm.swap_total *= 1024;
         }
       else if (!strncmp(str, "SwapFree:", sizeof(str)))
         {
@@ -567,7 +567,7 @@ proc_mem_t *get_proc_mem(void)
           return(NULL);
           }
 
-        /* mm.swap_free *= 1024; */
+        mm.swap_free *= 1024;
         }
       }
     while (fscanf(fp, "%30s", str) == 1);
@@ -2208,6 +2208,17 @@ int kill_task(
               log_buffer);
             }
 
+          if (LOGLEVEL >= 3)
+            {
+            sprintf(log_buffer, "%s: not killing process %d. Avoid sending signal because child task still has MOM's session id", id, ps->pid);
+
+            log_record(
+              PBSEVENT_JOB,
+              PBS_EVENTCLASS_JOB,
+              ptask->ti_job->ji_qs.ji_jobid,
+              log_buffer);
+            }
+
           continue;
           }  /* END if (ps->pid == mompid) */
 
@@ -2240,27 +2251,7 @@ int kill_task(
           for (i = 0;i < 20;i++)
             {
             /* check if process is gone */
-            if ((ps = get_proc_stat(ps->pid)) == NULL)
-              {
-              break;
-              }
-            else
-              {
-              sprintf(log_buffer, "%s: process (pid=%d/state=%c) after sig %d",
-                      id,
-                      ps->pid,
-                      ps->state,
-                      sig);
-              log_record(
-                PBSEVENT_JOB,
-                PBS_EVENTCLASS_JOB,
-                ptask->ti_job->ji_qs.ji_jobid,
-                log_buffer);
-              if (ps->state == 'Z')
-                break;
-              }
 
-            /* try to kill again */
             if (kill(ps->pid, 0) == -1)
               break;
 
@@ -3324,8 +3315,9 @@ static char *totmem(
     log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
     }
 
-  sprintf(ret_string, "%llukb",
-          (mm->mem_total + mm->swap_total )); /* KB */
+  sprintf(ret_string, "%lukb",
+
+          (ulong)((mm->mem_total >> 10) + (mm->swap_total >> 10))); /* KB */
 
   return(ret_string);
   }  /* END totmem() */
@@ -3369,8 +3361,9 @@ static char *availmem(
     log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
     }
 
-  sprintf(ret_string, "%llukb",
-          (mm->mem_free + mm->swap_free)); /* KB */
+  sprintf(ret_string, "%lukb",
+
+          (ulong)((mm->mem_free >> 10) + (mm->swap_free >> 10))); /* KB */
 
   return(ret_string);
   }  /* END availmem() */
@@ -3514,10 +3507,12 @@ static char *physmem(
 
     /* value specified in bytes */
 
-    /* mem >>= 10; */
+    mem >>= 10;
     }
 
-  sprintf(ret_string, "%llukb", mem);
+  sprintf(ret_string, "%llukb",
+
+          mem);
 
   return(ret_string);
   }  /* END physmem() */
@@ -3657,7 +3652,6 @@ char *size(
   }  /* END size() */
 
 
-
 /*
  * For a recovering (-p) mom, look through existing tasks in existing
  * jobs for things that have exited that are not owned by us through a
