@@ -134,17 +134,17 @@
 
 /* external functions called */
 
-extern int  pbsd_init A_((int));
+extern int  pbsd_init(int);
 extern void shutdown_ack();
-extern int  update_nodes_file A_((void));
+extern int  update_nodes_file(void);
 extern void tcp_settimeout(long);
 extern void poll_job_task(struct work_task *);
 extern int  schedule_jobs(void);
 extern int  notify_listeners(void);
-extern void queue_route A_((pbs_queue *));
+extern void queue_route(pbs_queue *);
 extern void svr_shutdown(int);
 extern void acct_close(void);
-extern int  svr_startjob A_((job *, struct batch_request *, char *, char *));
+extern int  svr_startjob(job *, struct batch_request *, char *, char *);
 extern int RPPConfigure(int, int);
 extern void acct_cleanup(long);
 #ifdef NO_SIGCHLD
@@ -166,22 +166,16 @@ extern void check_children();
 #ifndef bool_t
 #define bool_t unsigned char
 #endif
-#ifndef SUCCESS
-#define SUCCESS 1
-#endif 
-#ifndef FAILURE
-#define FAILURE 0
-#endif
 #define ISEMPTYSTR(STR)  ((STR)[0] == '\0')
 #ifndef MAX_CMD_ARGS
 #define MAX_CMD_ARGS 10
 #endif
 
 #ifdef USE_HA_THREADS
-static void lock_out_ha A_(());
+static void lock_out_ha ();
 #else
-static void lock_out A_((int,int));
-static int try_lock_out A_((int,int));
+static void lock_out (int,int);
+static int try_lock_out (int,int);
 #endif
 
 /* external data items */
@@ -195,14 +189,14 @@ extern int    get_svr_attr (int);
 
 /* Local Private Functions */
 
-static int    get_port A_((char *, unsigned int *, pbs_net_t *));
-static int    daemonize_server A_((int, pid_t *));
-int mutex_lock A_((mutex_t *));
-int mutex_unlock A_((mutex_t *));
-int get_file_info A_((char *,unsigned long *,long *,bool_t *,bool_t *));
-int get_full_path A_((char *,char *,int));
+static int    get_port (char *, unsigned int *, pbs_net_t *);
+static int    daemonize_server (int,int *);
+int mutex_lock (mutex_t *);
+int mutex_unlock (mutex_t *);
+int get_file_info (char *,unsigned long *,long *,bool_t *,bool_t *);
+int get_full_path (char *,char *,int);
 int svr_restart();
-void          restore_attr_default A_((struct attribute *));
+void          restore_attr_default (struct attribute *);
 
 /* Global Data Items */
 
@@ -259,9 +253,9 @@ int   server_init_type = RECOV_WARM;
 char         server_name[PBS_MAXSERVERNAME + 1]; /* host_name[:service|port] */
 int  svr_delay_entry = 0;
 int  svr_do_schedule = SCH_SCHEDULE_NULL;
-extern int  listener_command;
 tlist_head svr_queues;            /* list of queues                   */
 tlist_head svr_alljobs;           /* list of all jobs in server       */
+tlist_head svr_jobs_array_sum;    /* list of jobs in server, arrays summarized as single "placeholder" job */
 tlist_head svr_newjobs;           /* list of incoming new jobs        */
 tlist_head svr_newnodes;          /* list of newly created nodes      */
 tlist_head svr_jobarrays;         /* list of all job arrays           */
@@ -281,18 +275,17 @@ int             TForceUpdate = 0;  /* (boolean) */
 char           *ProgName;
 char           *NodeSuffix = NULL;
 
+int allow_any_mom = FALSE;
 
-
-void
-DIS_rpp_reset(void)
+void DIS_rpp_reset(void)
 
   {
   if (dis_getc != rpp_getc)
     {
     dis_getc    = rpp_getc;
-    dis_puts    = (int (*)A_((int, const char *, size_t)))rpp_write;
-    dis_gets    = (int (*)A_((int, char *, size_t)))rpp_read;
-    disr_skip   = (int (*)A_((int, size_t)))rpp_skip;
+    dis_puts    = (int (*)(int, const char *, size_t))rpp_write;
+    dis_gets    = (int (*)(int, char *, size_t))rpp_read;
+    disr_skip   = (int (*)(int, size_t))rpp_skip;
     disr_commit = rpp_rcommit;
     disw_commit = rpp_wcommit;
     }
@@ -320,8 +313,8 @@ void do_rpp(
 
   int  ret, proto, version;
 
-  void is_request A_((int, int, int *));
-  void stream_eof A_((int, u_long, int));
+  void is_request(int, int, int *);
+  void stream_eof(int, u_long, int);
 
   if (LOGLEVEL >= 4)
     {
@@ -477,7 +470,6 @@ clear_listeners(void)   /* I */
     listener_conns[i].address = 0;
     listener_conns[i].port = 0;
     listener_conns[i].sock = -1;
-    listener_conns[i].first_time = 1;
     }
 
   return;
@@ -578,7 +570,7 @@ void parse_command_line(int argc, char *argv[])
 
 
 
-  while ((c = getopt(argc, argv, "A:a:d:DfhH:L:l:M:p:R:S:t:v-:")) != -1)
+  while ((c = getopt(argc, argv, "A:a:d:DefhH:L:l:mM:p:R:S:t:v-:")) != -1)
     {
     switch (c)
       {
@@ -667,6 +659,10 @@ void parse_command_line(int argc, char *argv[])
 
         break;
 
+      case 'e':
+        allow_any_mom = TRUE;
+        break;
+
       case 'f':
 
         TForceUpdate = 1;
@@ -755,8 +751,6 @@ void parse_command_line(int argc, char *argv[])
 
       case 'l':
 
-        clear_listeners();
-
         if (get_port(
               optarg,
               &listener_port,
@@ -940,7 +934,7 @@ static time_t next_task()
   struct work_task  *nxt;
 
   struct work_task  *ptask;
-  time_t      tilwhen = server.sv_attr[(int)SRV_ATR_schedule_iteration].at_val.at_long;
+  time_t      tilwhen = server.sv_attr[(int)SRV_ATR_scheduler_iteration].at_val.at_long;
 
   time_now = time((time_t *)0);
 
@@ -982,10 +976,7 @@ static time_t next_task()
   /* should the scheduler be run?  If so, adjust the delay time  */
 
   if ((delay = server.sv_next_schedule - time_now) <= 0)
-    {
     svr_do_schedule = SCH_SCHEDULE_TIME;
-    listener_command = SCH_SCHEDULE_TIME;
-    }
   else if (delay < tilwhen)
     tilwhen = delay;
 
@@ -1046,10 +1037,10 @@ main_loop(void)
   time_t last_jobstat_time;
   int    when;
 
-  void ping_nodes A_((struct work_task *));
-  void check_nodes A_((struct work_task *));
-  void check_log A_((struct work_task *));
-  void check_acct_log A_((struct work_task *));
+  void ping_nodes(struct work_task *);
+  void check_nodes(struct work_task *);
+  void check_log(struct work_task *);
+  void check_acct_log(struct work_task *);
 
   extern char *msg_startup2; /* log message   */
 
@@ -1124,7 +1115,7 @@ main_loop(void)
     else
       waittime = next_task();
 
-    waittime = MAX(1, waittime);
+    waittime = MAX(0, waittime);
 
     if (*state == SV_STATE_RUN)
       {
@@ -1137,7 +1128,7 @@ main_loop(void)
         {
         server.sv_next_schedule =
           time_now +
-          server.sv_attr[(int)SRV_ATR_schedule_iteration].at_val.at_long;
+          server.sv_attr[(int)SRV_ATR_scheduler_iteration].at_val.at_long;
 
         schedule_jobs();
         notify_listeners();
@@ -1449,12 +1440,9 @@ int main(
 
   /* if we are not running with real and effective uid of 0, forget it */
 
-  if ((getuid() != 0) || (geteuid() != 0))
+  if (IamRoot() == 0)
     {
-    fprintf(stderr, "%s: must be run by root\n",
-            ProgName);
-
-    return(1);
+	return(1);
     }
 
   /*
@@ -1537,12 +1525,15 @@ int main(
     DEBUGMODE = 1;
     TDoBackground = 0;
     }
+#ifdef DISABLE_DAEMONS
+    TDoBackground = 0;
+#endif
 
   /* handle running in the background or not if we're debugging */
 
   if(high_availability_mode)
     {
-    if (daemonize_server(TDoBackground, &sid) == FAILURE)
+    if (daemonize_server(TDoBackground,&sid) == FAILURE)
       {
       exit(2);
       }
@@ -2001,10 +1992,10 @@ int is_ha_lock_file_valid(
 
   if (stat(LockDir,&Stat) != 0)
     {
-    char *tmpLine;
+    char tmpLine[MAX_LINE];
 
     /* stat failed */
-    tmpLine = strerror(errno);
+    strerror_r(errno,ErrorString,sizeof(ErrorString));
 
     snprintf(tmpLine,sizeof(tmpLine),"could not stat the lockfile dir '%s': %s",
       LockDir,
@@ -2274,12 +2265,12 @@ void *update_ha_lock_thread(
 
     if ((rc == -1) && !ISEMPTYSTR(HALockFile))
       {
-      char *ErrorString;
+      char ErrorString[MAX_LINE];
       /* error occurred--immediate shutdown needed */
 
       if (LocalErrno != 0)
         {
-        ErrorString = strerror(LocalErrno);
+        strerror_r(LocalErrno,ErrorString,sizeof(ErrorString));
 
         sprintf(log_buffer,"could not update HA lock file '%s' in heartbeat thread (%s - errno %d:%s)",
           HALockFile,
@@ -2460,7 +2451,10 @@ static void lock_out_ha()
 
     NumChecks++;
 
-    UseFLock = is_ha_lock_file_valid(HALockFile);
+    if (is_ha_lock_file_valid(HALockFile) == FALSE)
+      {
+      UseFLock = TRUE;
+      }
 
     if (UseFLock == TRUE)
       {
@@ -2564,7 +2558,7 @@ static void lock_out_ha()
 static int daemonize_server(
 
   int  DoBackground,  /* I */
-  pid_t *sid)           /* O */
+  int *sid)           /* O */
 
   {
   int    pid;          
