@@ -99,10 +99,10 @@
 #include "svrfunc.h"
 #include "sched_cmds.h"
 #include "csv.h"
+#include "log.h"
 
 extern int    scheduler_sock;
 extern int    svr_do_schedule;
-extern int    listener_command;
 extern time_t time_now;
 
 /*
@@ -441,7 +441,6 @@ int poke_scheduler(
     {
     if (pattr->at_val.at_long)
       svr_do_schedule = SCH_SCHEDULE_CMD;
-      listener_command = SCH_SCHEDULE_CMD;
     }
 
   return(0);
